@@ -37,7 +37,7 @@ def get_ps_env_var(var_group: str, var_name: str, local_creds: bool = False, pre
     try:
         client = create_client(local_creds)
         prefix = create_prefix(prefix)
-        return (client.get_parameter(Name=f'{prefix}/{var_group.lower()}/{var_name.lower()}')['Parameter']['Value'], None)
+        return (client.get_parameter(Name=f'/{prefix}/{var_group.lower()}/{var_name.lower()}')['Parameter']['Value'], None)
     except Exception as err:
         return (get_local_env_var(var_group, var_name), err)
 
@@ -50,7 +50,7 @@ def set_ps_env_var(var_group: str, var_name: str, var_val: str, local_creds: boo
     try:
         client = create_client(local_creds)
         prefix = create_prefix(prefix)
-        client.put_parameter(Name=f'{prefix}/{var_group.lower()}/{var_name.lower()}', Value=var_val, Overwrite=True)
+        client.put_parameter(Name=f'/{prefix}/{var_group.lower()}/{var_name.lower()}', Value=var_val, Overwrite=True)
         return (True, None)
     except Exception as err:
         return (False, err)
@@ -71,4 +71,4 @@ def create_prefix(prefix: str) -> str:
     '''
     Creates prefix for parameter store name
     '''
-    return prefix.rstrip('/') or f'{get_sys_env_var().capitalize()}/Tpds/'
+    return prefix.rstrip('/').lstrip('/') or f'{get_sys_env_var().capitalize()}/Tpds/'
